%{!?netcdfversion: %define netcdfversion 4.4.0}
%define netcdfnumversion %(echo %{netcdfversion} | tr -d .)
%{!?hdf5version: %define hdf5version 1.8.16}
%define hdf5numversion %(echo %{hdf5version} | tr -d .)
%{!?compiler: %define compiler gcc}

%define destdir /usr/local/pyferret/%{compiler}/netcdf-%{netcdfversion}/hdf5-%{hdf5version}/%{version}

# modules defaults
%define modulefile_path_top /usr/local/share/Modules/modulefiles/pyferret/gcc/netcdf-%{netcdfversion}/hdf5-%{hdf5version}

Version:	7.1.0
%define nversion %(echo %{version} | tr -d . )
Name:		pyferret%{nversion}-netcdf%{netcdfnumversion}-%{compiler}-hdf5-%{hdf5numversion}
%define rname	PyFerret
Release:	1%{?dist}
Summary:	The PyFerret program from NOAA/PMEL

Group:		Scientific/Libraries
License:	MIT
URL:		http://ferret.pmel.noaa.gov/Ferret/
# https://github.com/NOAA-PMEL/PyFerret/archive/v7.1.0-final.tar.gz
Source0:	PyFerret-%{version}-final.tar.gz

BuildRequires: netcdf%{netcdfnumversion}-%{compiler}-hdf5-%{hdf5numversion}-devel
BuildRequires: netcdf%{netcdfnumversion}-%{compiler}-hdf5-%{hdf5numversion}-static
BuildRequires: netcdf%{netcdfnumversion}-%{compiler}-hdf5-%{hdf5numversion}-extra-devel
BuildRequires: netcdf%{netcdfnumversion}-%{compiler}-hdf5-%{hdf5numversion}-extra-static
BuildRequires: hdf5-%{hdf5numversion}-%{compiler}-static
BuildRequires: zlib-static
BuildRequires: libX11-devel libXmu-devel readline-devel
BuildRequires: java-1.7.0-devel
BuildRequires: tcsh
BuildRequires: cairo-devel pixman-devel pango-devel libpng-devel
BuildRequires: freetype-devel fontconfig-devel glib2-devel
%if %{rhel} < 7
BuildRequires: python27-devel numpy27
%else
BuildRequires: python-devel numpy
%endif
Requires: netcdf%{netcdfnumversion}-%{compiler}-hdf5-%{hdf5numversion}
Requires: netcdf%{netcdfnumversion}-%{compiler}-hdf5-%{hdf5numversion}-extra

%description
Ferret is an interactive computer visualization and analysis environment designed
to meet the needs of oceanographers and meteorologists analyzing large and
complex gridded data sets.

%prep
%setup -q -n %{rname}-%{version}-final

%build
module load hdf5 netcdf python
perl -pi -e "s|^DIR_PREFIX\s+=.*|DIR_PREFIX = $PWD|" site_specific.mk
perl -pi -e 's|^BUILDTYPE\s+=.*|BUILDTYPE = x86_64-linux|' site_specific.mk
perl -pi -e 's|^PYTHON_EXE\s+=.*|PYTHON_EXE = python2.7|' site_specific.mk
perl -pi -e "s|^CAIRO_DIR\s+=.*|CAIRO_DIR = |" site_specific.mk
perl -pi -e "s|^PIXMAN_DIR\s+=.*|PIXMAN_DIR = |" site_specific.mk
#perl -pi -e "s|^HDF5_DIR\s+=.*|HDF5_DIR = $HDF5DIR|" site_specific.mk
perl -pi -e "s|^HDF5_DIR\s+=.*|HDF5_DIR = |" site_specific.mk
perl -pi -e "s|^COMPRESS_LIB\s+=.*|COMPRESS_LIB = sz|" site_specific.mk
perl -pi -e "s|^NETCDF4_DIR\s+=.*|NETCDF4_DIR = $NETCDFDIR|" site_specific.mk
export LD_X11=-lX11
#make %{?_smp_mflags}
# some of the extras don't build unless we specify BUILDTYPE here too.
# for pyferret also PYTHON_EXE
make BUILDTYPE=x86_64-linux PYTHON_EXE=python2.7

%install
mkdir -p $RPM_BUILD_ROOT%{destdir}
make install INSTALL_FER_DIR=$RPM_BUILD_ROOT%{destdir}
# remove tar files, needless duplication
cd $RPM_BUILD_ROOT%{destdir}
rm -f pyferret-latest-local.tar.gz

mkdir -p $RPM_BUILD_ROOT%{modulefile_path_top}
FER_DIR=%{destdir}
FER_DSETS="${FER_DIR}/fer_dsets"
cat <<ENDMODULE > ${RPM_BUILD_ROOT}%{modulefile_path_top}/%{version}
#%Module

# NOTE: This is an automatically-generated file!  (generated by the
# hdf5 rpm).  Any changes made here will be lost a) if the RPM is
# uninstalled, or b) if the RPM is upgraded or uninstalled.

proc ModulesHelp { } {
   puts stderr "This module adds ferret %{version} for compiled with hdf5 %{hdf5version} and netcdf %{netcdfversion} to your environment"
}   
    
module-whatis   "Sets up ferret %{version} compiled with hdf5 %{hdf5version} and netcdf %{netcdfversion} to your environment"

# first we load our dependencies
module load hdf5/%{compiler}/%{hdf5version} netcdf/gcc/hdf5-%{hdf5version}/%{netcdfversion}
setenv FER_DIR=%{destdir}
setenv FER_DSETS="${FER_DIR}/fer_dsets"
setenv FER_WEB_BROWSER="firefox"
prepend-path PATH "%{destdir}/bin"
prepend-path -d { } FER_DATA_THREDDS "http://ferret.pmel.noaa.gov/geoide/geoIDECleanCatalog.xml ${FER_DSETS}"

## Space-separated lists of directories examined when searching
## for (data, descriptor, grid, go-script) files without path components
prepend-path -d { } FER_DATA ". ${FER_DSETS}/data ${FER_DIR}/go ${FER_DIR}/examples"
prepend-path -d { } FER_DESCR ". ${FER_DSETS}/descr"
prepend-path -d { } FER_GRIDS ". ${FER_DSETS}/grids"
prepend-path -d { } FER_GO ". ${FER_DIR}/go ${FER_DIR}/examples ${FER_DIR}/contrib"

## Space-separated list of directories containing traditional
## Ferret external function files (shared-object libraries)
#prepend-path -d { } FER_EXTERNAL_FUNCTIONS "${FER_DIR}/ext_func/libs"
prepend-path -d { } PYFER_EXTERNAL_FUNCTIONS "${FER_DIR}/ext_func/pylibs"

## Space-separated list of directories for Ferret color palettes 
prepend-path -d { } FER_PALETTE ". ${FER_DIR}/ppl"
## Ferret's color palettes directory (old) 
setenv SPECTRA "${FER_DIR}/ppl"

## Directory for Ferret fonts 
setenv FER_FONTS "${FER_DIR}/ppl/fonts"
## Directory for Ferret fonts (old)
setenv PLOTFONTS "${FER_DIR}/ppl/fonts"

## Directory containing threddsBrowser.jar and toolsUI.jar for ThreddsBrowser 
setenv FER_LIBS "${FER_DIR}/lib"

## Ferret directory (old)
setenv FER_DAT="${FER_DIR}"

# Assign the directory containing the pyferret Python package (directory)
prepend-path PYTHONPATH "${FER_DIR}/lib/${python_subdir}/site-packages"

# Add $pysite/pyferret to the shared-object library search path given
# by LD_LIBRARY_PATH so libpyferret.so will be found
prepend-path LD_LIBRARY_PATH "${FER_DIR}/lib/${python_subdir}/site-packages/pyferret"
ENDMODULE

%files
%doc LICENSE README.md
%dir /usr/local/pyferret
%dir /usr/local/pyferret/%{compiler}
%dir /usr/local/pyferret/%{compiler}/netcdf-%{netcdfversion}
%dir /usr/local/pyferret/%{compiler}/netcdf-%{netcdfversion}/hdf5-%{hdf5version}
%{destdir}
%dir /usr/local/share/Modules/modulefiles/pyferret
%dir /usr/local/share/Modules/modulefiles/pyferret/gcc
%dir /usr/local/share/Modules/modulefiles/pyferret/gcc/netcdf-%{netcdfversion}
%dir %{modulefile_path_top}
%{modulefile_path_top}/%{version}

%changelog
* Sun Mar 19 2017 Josko Plazonic <plazonic@princeton.edu>
- initial build
